@@ -1,16 +1,18 @@
 ### R code from vignette source 'psych_for_sem.Rnw'
 
 ###################################################
-### code chunk number 1: psych_for_sem.Rnw:94-96
+### code chunk number 1: psych_for_sem.Rnw:96-99
 ###################################################
 if(!require(sem))  stop('The package sem is required to do these analyses')
+
 if(!require('GPArotation')) stop('The package GPArotation is required to do these analyses')
 
 
 ###################################################
-### code chunk number 2: psych_for_sem.Rnw:139-147
+### code chunk number 2: psych_for_sem.Rnw:144-153
 ###################################################
 library(psych)
+library(psychTools)
 set.seed(42)
 tau <- sim.congeneric(loads=c(.8,.8,.8,.8)) #population values
 tau.samp <- sim.congeneric(loads=c(.8,.8,.8,.8),N=100) # sample correlation matrix for 100 cases
@@ -21,21 +23,21 @@ dim(tau.samp$observed)
 
 
 ###################################################
-### code chunk number 3: psych_for_sem.Rnw:156-158
+### code chunk number 3: psych_for_sem.Rnw:162-164
 ###################################################
 cong <- sim.congeneric(N=100)
 round(cong,2)
 
 
 ###################################################
-### code chunk number 4: psych_for_sem.Rnw:164-166
+### code chunk number 4: psych_for_sem.Rnw:170-172
 ###################################################
 #plot.new()
 m1 <- structure.diagram(c("a","b","c","d"))
 
 
 ###################################################
-### code chunk number 5: psych_for_sem.Rnw:181-188
+### code chunk number 5: psych_for_sem.Rnw:187-194
 ###################################################
 set.seed(42)
 gload=matrix(c(.9,.8,.7),nrow=3)
@@ -47,7 +49,7 @@ round(bifact,2)
 
 
 ###################################################
-### code chunk number 6: psych_for_sem.Rnw:195-199
+### code chunk number 6: psych_for_sem.Rnw:201-205
 ###################################################
 op <- par(mfrow=c(1,2))
 m.bi <- omega(bifact,title="A bifactor model")
@@ -56,7 +58,7 @@ op <- par(mfrow = c(1,1))
 
 
 ###################################################
-### code chunk number 7: psych_for_sem.Rnw:217-220
+### code chunk number 7: psych_for_sem.Rnw:223-226
 ###################################################
 circ <- sim.circ(16)
 f2 <- fa(circ,2)
@@ -64,7 +66,7 @@ plot(f2,title="16 simulated variables in a circumplex pattern")
 
 
 ###################################################
-### code chunk number 8: psych_for_sem.Rnw:237-241
+### code chunk number 8: psych_for_sem.Rnw:243-247
 ###################################################
 set.seed(42)
 fx <- c(.9,.8,.7,.6)
@@ -73,7 +75,7 @@ cong1
 
 
 ###################################################
-### code chunk number 9: psych_for_sem.Rnw:247-251
+### code chunk number 9: psych_for_sem.Rnw:253-257
 ###################################################
 set.seed(42)
 fx  <- matrix(c(.9,.8,.7,rep(0,9),.7,.6,.5,rep(0,9),.6,.5,.4),   ncol=3)
@@ -82,14 +84,14 @@ three.fact
 
 
 ###################################################
-### code chunk number 10: psych_for_sem.Rnw:256-258
+### code chunk number 10: psych_for_sem.Rnw:262-264
 ###################################################
 #plot.new()
 three.fact.mod <-structure.diagram(fx)
 
 
 ###################################################
-### code chunk number 11: psych_for_sem.Rnw:267-272
+### code chunk number 11: psych_for_sem.Rnw:273-278
 ###################################################
 Phi = matrix(c(1,.5,.3,.5,1,.2,.3,.2,1), ncol=3)
 cor.f3 <- sim.structure(fx,Phi)
@@ -99,7 +101,7 @@ cor.f3
 
 
 ###################################################
-### code chunk number 12: psych_for_sem.Rnw:279-283
+### code chunk number 12: psych_for_sem.Rnw:285-289
 ###################################################
 fxs <- structure.list(9,list(F1=c(1,2,3),F2=c(4,5,6),F3=c(7,8,9)))
 Phis <- phi.list(3,list(F1=c(2,3),F2=c(1,3),F3=c(1,2)))
@@ -108,27 +110,27 @@ Phis #show this one as well
 
 
 ###################################################
-### code chunk number 13: psych_for_sem.Rnw:289-291
+### code chunk number 13: psych_for_sem.Rnw:295-297
 ###################################################
 #plot.new()
 corf3.mod <- structure.diagram(fxs,Phis)
 
 
 ###################################################
-### code chunk number 14: psych_for_sem.Rnw:302-303
+### code chunk number 14: psych_for_sem.Rnw:308-309
 ###################################################
 f3.p <- Promax(fa(cor.f3$model,3))
 
 
 ###################################################
-### code chunk number 15: psych_for_sem.Rnw:308-310
+### code chunk number 15: psych_for_sem.Rnw:314-316
 ###################################################
 #plot.new()
 mod.f3p <- structure.diagram(f3.p,cut=.2)
 
 
 ###################################################
-### code chunk number 16: psych_for_sem.Rnw:322-329
+### code chunk number 16: psych_for_sem.Rnw:328-335
 ###################################################
 set.seed(42)
 fx  <- matrix(c(.9,.8,.7,rep(0,9),.7,.6,.5,rep(0,9),.6,.5,.4),   ncol=3)
@@ -140,7 +142,7 @@ round(twelveV,2)
 
 
 ###################################################
-### code chunk number 17: psych_for_sem.Rnw:335-338
+### code chunk number 17: psych_for_sem.Rnw:341-344
 ###################################################
 fxs <- structure.list(9,list(X1=c(1,2,3), X2 =c(4,5,6),X3 = c(7,8,9)))
 phi <- phi.list(4,list(F1=c(4),F2=c(4),F3=c(4),F4=c(1,2,3)))
@@ -148,14 +150,14 @@ fyx <- structure.list(3,list(Y=c(1,2,3)),"Y")
 
 
 ###################################################
-### code chunk number 18: psych_for_sem.Rnw:343-345
+### code chunk number 18: psych_for_sem.Rnw:349-351
 ###################################################
 #plot.new()
 sg3 <- structure.diagram(fxs,phi,fyx)
 
 
 ###################################################
-### code chunk number 19: psych_for_sem.Rnw:358-365
+### code chunk number 19: psych_for_sem.Rnw:364-371
 ###################################################
 fxh  <- structure.list(9,list(X1=c(1:3),X2=c(4:6),X3=c(7:9),g=NULL))
 fy <- structure.list(3,list(Y=c(1,2,3)))
@@ -167,14 +169,14 @@ hi.mod <-structure.diagram(fxh,Phi, fy)
 
 
 ###################################################
-### code chunk number 20: psych_for_sem.Rnw:381-383
+### code chunk number 20: psych_for_sem.Rnw:387-389
 ###################################################
 principal(cong1$model)
 fa(cong1$model)
 
 
 ###################################################
-### code chunk number 21: psych_for_sem.Rnw:391-398
+### code chunk number 21: psych_for_sem.Rnw:397-404
 ###################################################
 pc3 <- principal(bifact,3)
 pa3 <- fa(bifact,3,fm="pa")
@@ -186,38 +188,38 @@ factor.congruence(list(pc3,pa3,ml3))
 
 
 ###################################################
-### code chunk number 22: psych_for_sem.Rnw:404-406
+### code chunk number 22: psych_for_sem.Rnw:410-412
 ###################################################
 ml3p <- Promax(ml3)
 ml3p
 
 
 ###################################################
-### code chunk number 23: psych_for_sem.Rnw:415-416
+### code chunk number 23: psych_for_sem.Rnw:421-422
 ###################################################
 om.bi <- omega(bifact)
 
 
 ###################################################
-### code chunk number 24: psych_for_sem.Rnw:428-429
+### code chunk number 24: psych_for_sem.Rnw:434-435
 ###################################################
 om.hi <- omega(bifact,sl=FALSE)
 
 
 ###################################################
-### code chunk number 25: psych_for_sem.Rnw:437-438
+### code chunk number 25: psych_for_sem.Rnw:443-444
 ###################################################
 om.bi
 
 
 ###################################################
-### code chunk number 26: psych_for_sem.Rnw:446-447
+### code chunk number 26: psych_for_sem.Rnw:452-453
 ###################################################
 ic <- ICLUST(bifact,title="Hierarchical cluster analysis of bifact data")
 
 
 ###################################################
-### code chunk number 27: psych_for_sem.Rnw:460-467
+### code chunk number 27: psych_for_sem.Rnw:466-473
 ###################################################
 fx <-matrix(c( .9,.8,.6,rep(0,4),.6,.8,-.7),ncol=2)  
 fy <- matrix(c(.6,.5,.4),ncol=1)
@@ -229,20 +231,20 @@ print(gre.gpa)
 
 
 ###################################################
-### code chunk number 28: psych_for_sem.Rnw:473-475
+### code chunk number 28: psych_for_sem.Rnw:479-481
 ###################################################
 esem.example <- esem(gre.gpa$model,varsX=1:5,varsY=6:8,nfX=2,nfY=1,n.obs=1000,plot=FALSE)
 esem.example
 
 
 ###################################################
-### code chunk number 29: psych_for_sem.Rnw:480-481
+### code chunk number 29: psych_for_sem.Rnw:486-487
 ###################################################
  esem.diagram(esem.example)
 
 
 ###################################################
-### code chunk number 30: psych_for_sem.Rnw:504-509
+### code chunk number 30: psych_for_sem.Rnw:510-515
 ###################################################
 library(sem)
  mod.tau <- structure.sem(c("a","a","a","a"),labels=paste("V",1:4,sep=""))
@@ -252,7 +254,7 @@ summary(sem.tau,digits=2)
 
 
 ###################################################
-### code chunk number 31: psych_for_sem.Rnw:514-519
+### code chunk number 31: psych_for_sem.Rnw:520-525
 ###################################################
 mod.cong <- structure.sem(c("a","b","c","d"),labels=paste("V",1:4,sep=""))
 mod.cong  #show the model
@@ -262,7 +264,7 @@ anova(sem.cong,sem.tau) #test the difference between the two models
 
 
 ###################################################
-### code chunk number 32: psych_for_sem.Rnw:530-535
+### code chunk number 32: psych_for_sem.Rnw:536-541
 ###################################################
 mod.one <- structure.sem(letters[1:9],labels=paste("V",1:9,sep=""))
 mod.one  #show the model
@@ -272,16 +274,16 @@ round(residuals(sem.one),2)
 
 
 ###################################################
-### code chunk number 33: psych_for_sem.Rnw:541-545
+### code chunk number 33: psych_for_sem.Rnw:547-551
 ###################################################
-f1 <- factanal(covmat=bifact,factors=1)
+f1 <- fa(bifact)
 mod.f1 <- structure.sem(f1)
 sem.f1 <- sem(mod.f1,bifact,100)
 sem.f1
 
 
 ###################################################
-### code chunk number 34: psych_for_sem.Rnw:554-559
+### code chunk number 34: psych_for_sem.Rnw:560-565
 ###################################################
 f3 <-fa(bifact,3,rotate="varimax")
 mod.f3 <- structure.sem(f3)
@@ -291,7 +293,7 @@ round(residuals(sem.f3),2)
 
 
 ###################################################
-### code chunk number 35: psych_for_sem.Rnw:568-571
+### code chunk number 35: psych_for_sem.Rnw:574-577
 ###################################################
 f3 <-fa(bifact,3)     #extract three factors and do an oblique rotation
 mod.f3 <- structure.sem(f3) #create the sem model
@@ -299,65 +301,65 @@ mod.f3   #show it
 
 
 ###################################################
-### code chunk number 36: psych_for_sem.Rnw:579-581
+### code chunk number 36: psych_for_sem.Rnw:585-587
 ###################################################
 #plot.new()
 mod.f3 <- structure.diagram(f3)
 
 
 ###################################################
-### code chunk number 37: psych_for_sem.Rnw:598-599
+### code chunk number 37: psych_for_sem.Rnw:604-605
 ###################################################
 om.th.bi  <- omega(Thurstone,digits=3)
 
 
 ###################################################
-### code chunk number 38: psych_for_sem.Rnw:608-611
+### code chunk number 38: psych_for_sem.Rnw:614-617
 ###################################################
-sem.bi <- sem(om.th.bi$model,Thurstone,213) #use the model created by omega
+sem.bi <- sem(om.th.bi$model$sem,Thurstone,213) #use the model created by omega
 summary(sem.bi,digits=2)
 stdCoef(sem.bi,digits=2)
 
 
 ###################################################
-### code chunk number 39: psych_for_sem.Rnw:624-625
+### code chunk number 39: psych_for_sem.Rnw:630-631
 ###################################################
 om.hi <- omega(Thurstone,digits=3,sl=FALSE)
 
 
 ###################################################
-### code chunk number 40: psych_for_sem.Rnw:633-637
+### code chunk number 40: psych_for_sem.Rnw:639-643
 ###################################################
-sem.hi <- sem(om.hi$model,Thurstone,213)
+sem.hi <- sem(om.hi$model$sem,Thurstone,213)
 summary(sem.hi,digits=2)
 stdCoef(sem.hi,digits=2)
 anova(sem.hi,sem.bi)
 
 
 ###################################################
-### code chunk number 41: psych_for_sem.Rnw:646-651
+### code chunk number 41: psych_for_sem.Rnw:652-657
 ###################################################
 om.holz.bi <- omega(Holzinger,4)
-sem.holz.bi <- sem(om.holz.bi$model,Holzinger,355)
+sem.holz.bi <- sem(om.holz.bi$model$sem,Holzinger,355)
 om.holz.hi <- omega(Holzinger,4,sl=FALSE)
-sem.holz.hi <- sem(om.holz.hi$model,Holzinger,355)
+sem.holz.hi <- sem(om.holz.hi$model$sem,Holzinger,355)
 anova(sem.holz.bi,sem.holz.hi)
 
 
 ###################################################
-### code chunk number 42: psych_for_sem.Rnw:661-662
+### code chunk number 42: psych_for_sem.Rnw:667-668
 ###################################################
 om.sem <- omegaSem(Thurstone,n.obs=213)
 
 
 ###################################################
-### code chunk number 43: psych_for_sem.Rnw:670-671
+### code chunk number 43: psych_for_sem.Rnw:676-677
 ###################################################
 omega.diagram(om.sem,sort=FALSE)
 
 
 ###################################################
-### code chunk number 44: psych_for_sem.Rnw:686-687
+### code chunk number 44: psych_for_sem.Rnw:692-693
 ###################################################
 sessionInfo()
 
